<?php if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Vatansms_SMS_Orders {

	private $enabled_buyers = false;
	private $enable_super_admin_sms = false;
	private $enable_product_admin_sms = false;

	public function __construct() {

		$this->enabled_buyers           = PWooSMS()->Options( 'enable_buyer' );
		$this->enable_super_admin_sms   = PWooSMS()->Options( 'enable_super_admin_sms' );
		$this->enable_product_admin_sms = PWooSMS()->Options( 'enable_product_admin_sms' );

		if ( $this->enabled_buyers || $this->enable_super_admin_sms || $this->enable_product_admin_sms ) {

			add_filter( 'woocommerce_checkout_fields', array( $this, 'mobileLabel' ), 0 );
			add_filter( 'woocommerce_billing_fields', array( $this, 'mobileLabel' ) );

			add_action( 'wp_enqueue_scripts', array( $this, 'checkoutScript' ) );
			add_action( 'woocommerce_after_order_notes', array( $this, 'checkoutFields' ) );
			add_action( 'woocommerce_checkout_process', array( $this, 'checkoutFieldsValidation' ) );
			add_action( 'woocommerce_checkout_update_order_meta', array( $this, 'saveSmsOrderMeta' ) );

			
			add_action( 'woocommerce_order_status_changed', array( $this, 'sendOrderSms' ), 99, 3 );

			
			add_action( 'woocommerce_checkout_order_processed', array( $this, 'sendOrderSms' ), 99, 1 );
			add_action( 'woocommerce_process_shop_order_meta', array( $this, 'sendOrderSms' ), 999, 1 );

			
			add_action( 'woocommerce_resume_order', function () {
				remove_action( 'woocommerce_checkout_order_processed', array( $this, 'sendOrderSms' ), 99 );
			} );

			add_filter( 'woocommerce_form_field_pwoosms_multiselect', array(
				'Vatansms_SMS_Helper',
				'multiSelectAndCheckbox'
			), 11, 4 );
			add_filter( 'woocommerce_form_field_pwoosms_multicheckbox', array(
				'Vatansms_SMS_Helper',
				'multiSelectAndCheckbox'
			), 11, 4 );

			if ( is_admin() ) {
				add_action( 'woocommerce_admin_order_data_after_billing_address', array(
					$this,
					'buyerSmsDetails'
				), 10, 1 );
				add_action( 'woocommerce_admin_order_data_after_order_details', array( $this, 'changeSmsTextJS' ) );
				add_action( 'wp_ajax_change_sms_text', array( $this, 'changeSmsTextCallback' ) );
				//add_action( 'wp_ajax_nopriv_change_sms_text', array( $this, 'changeSmsTextCallback' ) );
			}
		}
	}

	public function mobileLabel( $fields ) {

		$mobile_meta = PWooSMS()->buyerMobileMeta();

		if ( ! empty( $fields[ $mobile_meta ]['label'] ) ) {
			$fields[ $mobile_meta ]['label'] = PWooSMS()->Options( 'buyer_phone_label', $fields[ $mobile_meta ]['label'] );
		}

		if ( ! empty( $fields['billing'][ $mobile_meta ]['label'] ) ) {
			$fields['billing'][ $mobile_meta ]['label'] = PWooSMS()->Options( 'buyer_phone_label', $fields['billing'][ $mobile_meta ]['label'] );
		}

		return $fields;
	}

	public function checkoutScript() {

		if ( ! function_exists( 'is_checkout' ) || ! function_exists( 'wc_enqueue_js' ) ) {
			return;
		}

		if ( PWooSMS()->Options( 'allow_buyer_select_status' ) && is_checkout() ) {

			wp_register_script( 'pwoosms-frontend-js', PWOOSMS_URL . '/assets/js/multi-select.js', array( 'jquery' ), PWOOSMS_VERSION, true );
			wp_localize_script( 'pwoosms-frontend-js', 'pwoosms',
				array(
					'ajax_url'                  => admin_url( 'admin-ajax.php' ),
					'chosen_placeholder_single' => 'İstediğiniz seçeneği seçin.',
					'chosen_placeholder_multi'  => 'İstediğiniz seçeneği seçin.',
					'chosen_no_results_text'    => 'Seçenek yok.',
				)
			);
			wp_enqueue_script( 'pwoosms-frontend-js' );

			if ( ! PWooSMS()->Options( 'force_enable_buyer' ) ) {
				wc_enqueue_js( "
					jQuery( '#buyer_sms_status_field' ).hide();
					jQuery( 'input[name=buyer_sms_notify]' ).change( function () {
						if ( jQuery( this ).is( ':checked' ) )
							jQuery( '#buyer_sms_status_field' ).show();
						else
							jQuery( '#buyer_sms_status_field' ).hide();
					} ).change();
				" );
			}
		}
	}

	public function checkoutFields( $checkout ) {

		if ( ! $this->enabled_buyers || count( PWooSMS()->GetBuyerAllowedStatuses() ) < 0 ) {
			return;
		}

		echo '<div id="checkoutFields">';

		$checkbox_text = PWooSMS()->Options( 'buyer_checkbox_text', 'Siparişin durumunu SMS ile bilmek istiyorum.' );
		$required      = PWooSMS()->Options( 'force_enable_buyer' );
		if ( ! $required ) {
			woocommerce_form_field( 'buyer_sms_notify',
				array(
					'type'        => 'checkbox',
					'class'       => array( 'buyer-sms-notify form-row-wide' ),
					'label'       => $checkbox_text,
					'label_class' => '',
					'required'    => false,
				), $checkout->get_value( 'buyer_sms_notify' )
			);
		}

		if ( PWooSMS()->Options( 'allow_buyer_select_status' ) ) {
			$multiselect_text        = PWooSMS()->Options( 'buyer_select_status_text_top' );
			$multiselect_text_bellow = PWooSMS()->Options( 'buyer_select_status_text_bellow' );
			$required                = PWooSMS()->Options( 'force_buyer_select_status' );
			$mode                    = PWooSMS()->Options( 'buyer_status_mode', 'selector' ) == 'selector' ? 'pwoosms_multiselect' : 'pwoosms_multicheckbox';
			woocommerce_form_field( 'buyer_sms_status', array(
				'type'        => $mode ? $mode : '',
				'class'       => array( 'buyer-sms-status form-row-wide wc-enhanced-select' ),
				'label'       => $multiselect_text,
				'options'     => PWooSMS()->GetBuyerAllowedStatuses( true ),
				'required'    => $required,
				'description' => $multiselect_text_bellow,
			), $checkout->get_value( 'buyer_sms_status' ) );
		}

		echo '</div>';
	}

	public function checkoutFieldsValidation() {

		$mobile_meta = PWooSMS()->buyerMobileMeta();

		if ( ! empty( $_POST[ $mobile_meta ] ) ) {
			$_POST[ $mobile_meta ] = PWooSMS()->modifyMobile( $_POST[ $mobile_meta ] );
		} else {
			$_POST[ $mobile_meta ] = '';
		}

		if ( ! $this->enabled_buyers || count( PWooSMS()->GetBuyerAllowedStatuses() ) < 0 ) {
			return;
		}

		$force_buyer = PWooSMS()->Options( 'force_enable_buyer' );

		if ( ! $force_buyer && ! empty( $_POST['buyer_sms_notify'] ) && empty( $_POST[ $mobile_meta ] ) ) {
			wc_add_notice( 'Kısa mesaj almak için cep telefonu numaranızı girmelisiniz.', 'error' );
		}

		$buyer_selected = $force_buyer || ( ! $force_buyer && ! empty( $_POST['buyer_sms_notify'] ) );
		if ( $buyer_selected && ! PWooSMS()->validateMobile( $_POST[ $mobile_meta ] ) ) {
			wc_add_notice( 'Cep telefonu numarası geçerli değil.', 'error' );
		}

		if ( $buyer_selected && empty( $_POST['buyer_sms_status'] ) && PWooSMS()->Options( 'allow_buyer_select_status' ) && PWooSMS()->Options( 'force_buyer_select_status' ) ) {
			wc_add_notice( 'SMSi almak için siparişin durumundan en az birini seçmek gerekir.', 'error' );
		}
	}

	public function saveSmsOrderMeta( $order_id ) {

		if ( ! $this->enabled_buyers || count( PWooSMS()->GetBuyerAllowedStatuses() ) <= 0 ) {
			return;
		}

		update_post_meta( $order_id, '_force_enable_buyer', PWooSMS()->Options( 'force_enable_buyer', '__' ) );
		update_post_meta( $order_id, '_allow_buyer_select_status', PWooSMS()->Options( 'allow_buyer_select_status', '__' ) );

		if ( ! empty( $_POST['buyer_sms_notify'] ) || PWooSMS()->Options( 'force_enable_buyer' ) ) {
			update_post_meta( $order_id, '_buyer_sms_notify', 'yes' );
		} else {
			delete_post_meta( $order_id, '_buyer_sms_notify' );
		}

		if ( ! empty( $_POST['buyer_sms_status'] ) ) {
			$statuses = is_array( $_POST['buyer_sms_status'] ) ? array_map( 'sanitize_text_field', $_POST['buyer_sms_status'] ) : sanitize_text_field( $_POST['buyer_sms_status'] );
			update_post_meta( $order_id, '_buyer_sms_status', $statuses );
		} else {
			delete_post_meta( $order_id, '_buyer_sms_status' );
		}
	}

	public function buyerSmsDetails( $order ) {

		if ( ! $this->enabled_buyers || count( PWooSMS()->GetBuyerAllowedStatuses() ) < 0 ) {
			return;
		}

		$order_id = PWooSMS()->OrderId( $order );

		$mobile = PWooSMS()->buyerMobile( $order_id );

		if ( empty( $mobile ) ) {
			return;
		}

		if ( ! PWooSMS()->validateMobile( $mobile ) ) {
			echo '<p>Müşteri cep telefonu numarası geçerli değil.</p>';

			return;
		}

		if ( PWooSMS()->maybeBool( get_post_meta( $order_id, '_force_enable_buyer', true ) ) ) {
			echo '<p>Müşterinin, SMSnin alınıp alınmayacağını seçme hakkı yoktur.</p>';
		} else {
			$want_sms = get_post_meta( $order_id, '_buyer_sms_notify', true );
			echo '<p>Müşteri kısa mesaj almak istiyor mu? : ' . ( PWooSMS()->maybeBool( $want_sms ) ? 'evet' : 'hayır' ) . '</p>';
		}

		echo '<p>';
		if ( PWooSMS()->maybeBool( get_post_meta( $order_id, '_allow_buyer_select_status', true ) ) ) {

			$buyer_sms_status = (array) get_post_meta( $order_id, '_buyer_sms_status', true );
			$buyer_sms_status = array_filter( $buyer_sms_status );

			echo 'SMS almak için müşteri durum seçenekleri : ';
			if ( ! empty( $buyer_sms_status ) ) {
				$statuses = array();
				foreach ( $buyer_sms_status as $status ) {
					$statuses[] = PWooSMS()->statusName( $status );
				}

				echo implode( ' - ', $statuses );
			} else {
				echo 'Hiçbir durum seçilmedi.';
			}

		} else {
			echo 'Müşteri, SMS alma durumunu seçme hakkına sahip değildir ve eklentinin ayarlarını takip eder.';
			
		}
		echo '</p>';
	}

	public function sendOrderSms( $order_id, $old_status = '', $new_status = 'created' ) {

		if ( current_action() == 'woocommerce_process_shop_order_meta' ) {
			if ( ! is_admin() ) {
				return;
			}
		} else {
			remove_action( 'woocommerce_process_shop_order_meta', array( $this, 'sendOrderSms' ), 999 );
		}

		$new_status = PWooSMS()->modifyStatus( $new_status );

		if ( ! $order_id ) {
			return;
		}

		$order = new WC_Order( $order_id );

		//customer
		$order_page = ! empty( $_POST['is_shop_order'] ) && $_POST['is_shop_order'] == 'true';

		if ( ( $order_page && ! empty( $_POST['sms_order_send'] ) ) || ( ! $order_page && $this->buyerCanGetSMS( $order_id, $new_status ) ) ) {

			$mobile  = PWooSMS()->buyerMobile( $order_id );
			$message = isset( $_POST['sms_order_text'] ) ? esc_textarea( $_POST['sms_order_text'] ) : PWooSMS()->Options( 'sms_body_' . $new_status );

			$data = array(
				'post_id' => $order_id,
				'type'    => 2,
				'mobile'  => $mobile,
				'message' => PWooSMS()->ReplaceShortCodes( $message, $new_status, $order )
			);

			if ( ( $result = PWooSMS()->SendSMS( $data ) ) === true ) {
				$order->add_order_note( sprintf( 'SMS başarıyla gönderildi %s ', $mobile ) );
			} else {
				$order->add_order_note( sprintf( 'Hata! %s .<br>Sonuc: %s', $mobile, $result ) );
			}
		}


		//superAdmin
		if ( $this->enable_super_admin_sms && in_array( $new_status, (array) PWooSMS()->Options( 'super_admin_order_status' ) ) ) {

			$mobile  = PWooSMS()->Options( 'super_admin_phone' );
			$message = PWooSMS()->Options( 'super_admin_sms_body_' . $new_status );

			$data = array(
				'post_id' => $order_id,
				'type'    => 4,
				'mobile'  => $mobile,
				'message' => PWooSMS()->ReplaceShortCodes( $message, $new_status, $order )
			);

			if ( ( $result = PWooSMS()->SendSMS( $data ) ) === true ) {
				$order->add_order_note( sprintf( 'SMS başarıyla gönderildi %s .', $mobile ) );
			} else {
				$order->add_order_note( sprintf( 'Hata! %s .<br>Sonuc: %s', $mobile, $result ) );
			}
		}

		//productAdmin
		if ( $this->enable_product_admin_sms ) {

			$order_products = PWooSMS()->GetProdcutLists( $order, 'product_id' );
			$mobiles        = PWooSMS()->ProductAdminMobiles( $order_products['product_id'], $new_status );

			foreach ( (array) $mobiles as $mobile => $product_ids ) {

				$vendor_items = PWooSMS()->ProductAdminItems( $order_products, $product_ids );
				$message      = PWooSMS()->Options( 'product_admin_sms_body_' . $new_status );

				$data = array(
					'post_id' => $order_id,
					'type'    => 5,
					'mobile'  => $mobile,
					'message' => PWooSMS()->ReplaceShortCodes( $message, $new_status, $order, $vendor_items )
				);

				if ( ( $result = PWooSMS()->SendSMS( $data ) ) === true ) {
					$order->add_order_note( sprintf( 'SMS başarıyla gönderildi %s .', $mobile ) );
				} else {
					$order->add_order_note( sprintf( 'Hata! %s .<br>Sonuc: %s', $mobile, $result ) );
				}
			}
		}
	}

	public function changeSmsTextJS( $order ) {

		$order_id = PWooSMS()->OrderId( $order );

		if ( $this->enabled_buyers && PWooSMS()->validateMobile( PWooSMS()->buyerMobile( $order_id ) ) ) { ?>
            <script type="text/javascript">
                jQuery( document ).ready( function ( $ ) {
                    $( "#order_status" ).change( function () {
                        $( "#pwoosms_textbox" ).html( "<img src=\"<?php echo PWOOSMS_URL ?>/assets/images/ajax-loader.gif\" />" );
                        var order_status = $( "#order_status" ).val();
                        $.ajax( {
                            url: "<?php echo admin_url( "admin-ajax.php" ) ?>",
                            type: "post",
                            data: {
                                action: "change_sms_text",
                                security: "<?php echo wp_create_nonce( "change-sms-text" ) ?>",
                                order_id: "<?php echo $order_id; ?>",
                                order_status: order_status
                            },
                            success: function ( response ) {
                                $( "#pwoosms_textbox" ).html( response );
                            }
                        } );
                    } );
                } );
            </script>
            <p class="form-field form-field-wide" id="pwoosms_textbox_p">
                <span id="pwoosms_textbox" class="pwoosms_textbox"></span>
            </p>
			<?php
		}
	}

	public function changeSmsTextCallback() {

		check_ajax_referer( 'change-sms-text', 'security' );

		if ( ! empty( $_POST['order_id'] ) ) {

			$new_status = '';
			if ( isset( $_POST['order_status'] ) ) {
				$_order_status = is_array( $_POST['order_status'] ) ? array_map( 'sanitize_text_field', $_POST['order_status'] ) : sanitize_text_field( $_POST['order_status'] );
				$new_status    = PWooSMS()->modifyStatus( $_order_status );
			}

			$order_id = intval( $_POST['order_id'] );
			$order    = new WC_Order( $order_id );
			$message  = PWooSMS()->Options( 'sms_body_' . $new_status );
			$message  = PWooSMS()->ReplaceShortCodes( $message, $new_status, $order );

			echo '<textarea id="sms_order_text" name="sms_order_text" style="width:100%;height:120px;"> ' . $message . ' </textarea>';
			echo '<input type="hidden" name="is_shop_order" value="true" />';

			if ( $this->buyerCanGetSMS( $order_id, $new_status ) ) {
				$sms_checked = 'checked="checked"';
				$description = 'Ayarlara ve seçeneklere bağlı olarak, müşteri bu SMSi almalıdır. Ancak bu onay kutusu aracılığıyla SMS göndermeyi devre dışı bırakabilirsiniz.';
			} else {
				$sms_checked = '';
				$description = 'Ayarlara ve seçeneklere bağlı olarak, müşteri bu SMSi almamalıdır. Ancak bu onay kutusu aracılığıyla SMS göndermeyi etkinleştirebilirsiniz.';
			}

			echo '<input type="checkbox" id="sms_order_send" class="sms_order_send" name="sms_order_send" value="true" style="margin-top:2px;width:20px; float:right" ' . $sms_checked . '/>
					<label class="sms_order_send_label" for="sms_order_send" >Müşteriye SMS gönder</label>
					<span class="description">' . $description . '</span>';

		} else {
			echo 'Hata!.';
		}
		die();
	}

	public function buyerCanGetSMS( $order_id, $new_status ) {

		if ( ! $this->enabled_buyers ) {
			return false;
		}

		$order_id = intval( $order_id );

		if ( ! $order_id ) {
			return false;
		}

		$order = new WC_Order( $order_id );

		$allowed_status = array_keys( PWooSMS()->GetBuyerAllowedStatuses() );

		if ( is_admin() ) {
			$status      = PWooSMS()->OrderProp( $order, 'status' );
			$created_via = PWooSMS()->OrderProp( $order, 'created_via' );
			if ( $created_via == 'admin' || ! in_array( $status, array_keys( PWooSMS()->GetAllStatuses() ) ) ) {
				update_post_meta( $order_id, '_force_enable_buyer', PWooSMS()->Options( 'force_enable_buyer', '__' ) );
				update_post_meta( $order_id, '_allow_buyer_select_status', PWooSMS()->Options( 'allow_buyer_select_status', '__' ) );
				update_post_meta( $order_id, '_buyer_sms_notify', 'yes' );
				update_post_meta( $order_id, '_buyer_sms_status', $allowed_status );
			}
		}


		if ( ! PWooSMS()->validateMobile( PWooSMS()->buyerMobile( $order_id ) ) ) {
			return false;
		}

		if ( in_array( $new_status, $allowed_status ) && PWooSMS()->maybeBool( get_post_meta( $order_id, '_buyer_sms_notify', true ) ) ) {

			$buyer_sms_status    = (array) get_post_meta( $order_id, '_buyer_sms_status', true );
			$allow_select_status = PWooSMS()->maybeBool( get_post_meta( $order_id, '_allow_buyer_select_status', true ) );

			if ( ! $allow_select_status || ( $allow_select_status && in_array( $new_status, $buyer_sms_status ) ) ) {
				return true;
			}
		}

		return false;
	}
}

new Vatansms_SMS_Orders();