<?php if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Vatansms_SMS_Settings {

	private $settings_api;

	public function __construct() {

		$this->settings_api = new Vatansms_SMS_Settings_Api;

		add_action( 'init', array( $this, 'updateOption__3_8' ) );

		if ( is_admin() ) {

			add_action( 'admin_init', array( $this, 'adminInit' ) );
			add_action( 'admin_menu', array( $this, 'adminMenu' ), 60 );
			add_filter( 'woocommerce_settings_tabs_array', array( $this, 'adminSubMenu' ), 99999 );
			add_action( 'wp_before_admin_bar_render', array( $this, 'adminBar' ) );

			add_filter( 'pwoosms_buyer_settings', array( $this, 'buyerSettings' ) );
			add_filter( 'pwoosms_super_admin_settings', array( $this, 'superAdminSettings' ) );
			add_filter( 'pwoosms_product_admin_settings', array( $this, 'productAdminSettings' ) );

			add_filter( 'admin_footer_text', array( $this, 'footerNote' ) );
			add_filter( 'update_footer', array( $this, 'footerVersion' ), 11 );
		}
	}

	public function updateOption__3_8() {

		if ( get_option( 'pwoosms_update_gateway_options' ) ) {
			return;
		}

		global $wpdb;

		$wpdb->query( "UPDATE {$wpdb->options} SET option_value=REPLACE(option_value, 's:24:\"persian_woo_sms_username\"', 's:20:\"sms_gateway_username\"') WHERE option_name='sms_main_settings'" );
		$wpdb->query( "UPDATE {$wpdb->options} SET option_value=REPLACE(option_value, 's:24:\"persian_woo_sms_password\"', 's:20:\"sms_gateway_password\"') WHERE option_name='sms_main_settings'" );
		$wpdb->query( "UPDATE {$wpdb->options} SET option_value=REPLACE(option_value, 's:22:\"persian_woo_sms_sender\"', 's:18:\"sms_gateway_sender\"') WHERE option_name='sms_main_settings'" );
		update_option( 'pwoosms_update_gateway_options', '1' );
	}

	public function adminMenu() {

		$PSWoo_version = defined( 'PERSIAN_WOOCOMMERCE_VERSION' ) ? PERSIAN_WOOCOMMERCE_VERSION : '';
		if ( empty( $PSWoo_version ) ) {
			$PSWoo_version = defined( 'PW_VERSION' ) ? PW_VERSION : '1';
		}

		$slug = version_compare( $PSWoo_version, '2.4.9', '>' ) ? 'persian-wc' : 'woocommerce';

		add_submenu_page( $slug, 'VatanSMS2', '<img src="https://www.vatansms.com/assets/images/favicon.png" width="15"></img>VatanSMS',
			'manage_woocommerce', 'vatansms-woocommerce-sms-pro', array( $this, 'settingPage' ) );
	}

	public function adminInit() {

		if ( ! empty( $_GET['tab'] ) && $_GET['tab'] == 'pwoosms_settings_page' ) {
			wp_redirect( admin_url( 'admin.php?page=vatansms-woocommerce-sms-pro' ) );
			exit();
		}

		$this->settings_api->set_sections( self::settingSections() );
		$this->settings_api->set_fields( $this->settingFields() );
		$this->settings_api->admin_init();
	}

	public function adminSubMenu( $pages ) {
		$pages['pwoosms_settings_page'] = 'SMS';

		return $pages;
	}

	public function settingPage() {
		echo '<div class="wrap woocommerce">';
		$this->settings_api->show_navigation();
		$this->settings_api->show_forms();
		echo '</div>';
	}

	public function adminBar() {
		if ( PWooSMS()->Options( 'enable_admin_bar' ) ) {
			if ( current_user_can( 'manage_woocommerce' ) && is_admin_bar_showing() ) {
				global $wp_admin_bar;
				$wp_admin_bar->add_menu( array(
					'id'    => 'adminBar_send',
					'title' => '<img src="https://www.vatansms.com/assets/images/favicon.png" style="width:15px;"></img>VatanSMS WooCommerce',
					'href'  => admin_url( 'admin.php?page=vatansms-woocommerce-sms-pro&tab=send' ),
				) );
			}
		}
	}

	public static function settingSections() {
		$sections = array(
			array(
				'id'    => 'sms_main_settings',
				'title' => 'Ayarlar'
			),
			array(
				'id'    => 'sms_super_admin_settings',
				'title' => 'Yöneticiye SMS'
			),
			array(
				'id'    => 'sms_buyer_settings',
				'title' => 'Müşterilere SMS',

			),
			array(
				'id'    => 'sms_product_admin_settings',
				'title' => 'Çoklu Satıcı'
			),
			array(
				'id'       => 'sms_send',
				'title'    => 'Toplu SMS Gönder',
				'form_tag' => false
			),
			array(
				'id'       => 'sms_archive',
				'title'    => 'SMS Raporları',
				'form_tag' => false
			),
		);

		return apply_filters( 'pwoosms_settings_sections', $sections );
	}

	public function settingFields() {

		$gateway = PWooSMS()->Options( 'sms_gateway' );
		$gateway = ! empty( $gateway ) && $gateway != 'none';

		$gateways_list = class_exists( 'Vatansms_SMS_Gateways' ) ? Vatansms_SMS_Gateways::get_sms_gateway() : array();
		asort( $gateways_list );
		$gateways_list = array_merge($gateways_list );

		$shortcode = PWooSMS_Shortcode( true );

		$settings_fields = array(

			'sms_main_settings' => apply_filters( 'pwoosms_main_settings', array(
				array(
					'name'    => 'sms_gateway',
					'label'   => 'WEB SERVER',
					'type'    => 'select',
					'default' => 'vatansms',
					'value' => 'vatansms',
					'options' => $gateways_list,
					'ltr'     => true,
				),
				array(
					'name'  => 'sms_gateway_username',
					'label' => 'KULLANICI ADI',
					'desc'  => 'VatanSMS paneline giriş için kullandığınız KULLANICI ADI',
					'type'  => 'text',
					'ltr'   => true,
				),
				array(
					'name'  => 'sms_gateway_password',
					'label' => 'KULLANICI SIFRE',
					'desc'  => 'VatanSMS paneline giriş için kullandığınız ŞİFRE ',
					'type'  => 'text',
					'ltr'   => true,
				),
				array(
					'name'  => 'sms_gateway_kno',
					'label' => 'MÜŞTERİ KODU',
					'desc'  => 'VatanSMS paneline giriş yaptıktan sonra göreceğiniz 5 haneli MÜŞTERİ KODUNUZ',
					'type'  => 'text',
					'ltr'   => true,
				),
				array(
					'name'  => 'sms_gateway_sender',
					'label' => 'GÖNDERİCİ ADI(SMS BAŞLIĞI)',
					'type'  => 'text',
					'ltr'   => true,
				),
				array(
					'name'  => 'enable_admin_bar',
					'label' => 'Üst menüye VatanSMS ekle',
					'desc'  => 'Bu seçenek etkinleştirildiğinde, daha hızlı erişim için VatanSMS sms gönderme kısa yolu, yönetici üst menüsüne eklenir. ',
					'type'  => 'checkbox',
				),
			) ),

			'sms_super_admin_settings' => apply_filters( 'pwoosms_super_admin_settings', array(
				array(
					'name'    => 'enable_super_admin_sms',
					'label'   => 'Yöneticilere SMS gönder',
					'desc'    => 'Bu seçenek etkinleştirildiğinde, sipariş kaydedilirken veya değiştirilirken aşağıdaki alanda yazılı numaralara bilgilendirme mesajı yolla.',
					'type'    => 'checkbox',
					'default' => 'no'
				),
				array(
					'name'  => 'super_admin_phone',
					'label' => 'SMS gönderilecek kişilerin cep telefonları',
					'desc'  => 'Cep telefonu numaralarını virgülle (,) ayırın. Örnek telefon formatı: 05553332211 ',
					'type'  => 'text',
					'ltr'   => true,
				),
				array(
					'name'    => 'super_admin_order_status',
					'label'   => 'SMS alma durumu',
					'desc'    => 'Sitenin genel yöneticilerinin hangi durumlarda SMS siparişinden alacağını belirtebilirsiniz.',
					'type'    => 'multicheck',
					'options' => PWooSMS()->GetAllSuperAdminStatuses(),
				),
				array(
					'name'  => 'header_super_admin',
					'label' => '<h2>İşlem Durumuna Göre Gönderilecek SMS İçeriği Ayarları </h2>',
					'type'  => 'html',
				),
				array(
					'name'  => 'sms_body_shortcodes_super_admin',
					'label' => 'Kullanılabilir kısa kodlar',
					'type'  => 'html',
					'desc'  => $this->ShortCodes(),
				),
			) ),

			'sms_buyer_settings' => apply_filters( 'pwoosms_buyer_settings', array(
				array(
					'name'  => 'enable_buyer',
					'label' => 'Müşteriye SMS gönder',
					'desc'  => 'Bu seçeneği etkinleştirerek, siparişin durumunu kaydederken veya değiştirirken veya toplu olarak müşteriye bir SMS gönderilir.',
					'type'  => 'checkbox',
				),
				array(
					'name'  => 'enable_metabox',
					'label' => 'Metabox SMS gönder',
					'desc'  => 'Bu seçenek etkinleştirildiğinde, müşteriye SMS gönderme özelliği etkinleştirilirse, müşterilere SMS gönderme Metabax sipariş sayfasına eklenir.',
					'type'  => 'checkbox',
				),
				array(
					'name'    => 'buyer_phone_label',
					'label'   => 'Mobil Alan Başlığı',
					'desc'    => 'Bu başlık yerleşim sayfasında görüntülenecek ve "telefon" kelimesinin yerini alacak.',
					'type'    => 'text',
					'default' => 'Mobıle numara',
				),
				array(
					'name'    => 'force_enable_buyer',
					'label'   => 'İsteğe bağlı SMS gönder',
					'desc'    => 'Bu seçeneği etkinleştirerek, SMS ile bilgilendirme tercihini müşteriye bırakmış olursunuz. Aksi takdirde, müşterinize SMS her zaman gönderilir. ',
					'type'    => 'radio',
					'default' => 'yes',
					'options' => array(
						'no'  => 'Müşteri isteğine bağlı', // inja no mishe bale , yes mishe kheyr :D... doroste. moshkeli nis.
						'yes' => 'SMS her zaman gönder',
					)
				),
				array(
					'name'    => 'buyer_checkbox_text',
					'label'   => 'SMS onayı için görünecek metin ',
					'desc'    => 'Yerleşim sayfasında SMS seçildiğinde bu metin onay kutusunun üstünde görüntülenir.',
					'type'    => 'text',
					'default' => 'Siparişin durumunu SMS ile bilmek istiyorum.'
				),
				array(
					'name'  => 'header_2',
					'label' => '<h2>SMS durumu</h2>',
					'type'  => 'html',
				),
				array(
					'name'    => 'order_status',
					'label'   => 'SMS alma durumu',
					'desc'    => 'Müşterinin hangi durumlarda kısa mesaj alabileceğini belirleyebilirsiniz.',
					'type'    => 'multicheck',
					'options' => PWooSMS()->GetAllStatuses(),
				),
				array(
					'name'    => 'allow_buyer_select_status',
					'label'   => 'Müşteri SMS durumu tercihi',
					'desc'    => 'Bu seçeneği etkinleştirerek, müşteri SMS tercihi kısmından duruma göre seçim yapabilir. Bu bölüm etkinleştirilmezse, yukarıda seçilen tüm durumlarda SMS gönderilir. ',
					'type'    => 'radio',
					'default' => 'no',
					'options' => array(
						'yes' => 'evet',
						'no'  => 'hayir'
					)
				),
				array(
					'name'    => 'force_buyer_select_status',
					'label'   => 'En az bir durum seçmek gerekir',
					'desc'    => 'Bu seçeneği etkinleştirerek, kullanıcı yukarıda seçilen seçeneklerden en az bir sipariş durumu seçmelidir. Bu bölüm, "Müşteri Durum Seçimi" nin "Evet" ayarını gerektirir.',
					'type'    => 'radio',
					'default' => 'no',
					'options' => array(
						'yes' => 'evet',
						'no'  => 'hayir'
					)
				),
				array(
					'name'    => 'buyer_status_mode',
					'label'   => 'Durum seçimi türü',
					'desc'    => 'Bu bölüm seçildiğinde “Müşteri durum seçimi” ayarlarının da yapılmış olması gerekir. Alan türü, müşterinin sipariş durumu seçimini belirler. ',
					'type'    => 'radio',
					'default' => 'selector',
					'options' => array(
						'selector' => 'Çoklu seçenek',
						'checkbox' => 'Çek kutusu'
					)
				),
				array(
					'name'    => 'buyer_select_status_text_top',
					'label'   => 'SMS durum tercih kısmı başlığı ',
					'desc'    => 'Müşteri SMS durum tercihi kısmı için görünecek başlık. ',
					'type'    => 'text',
					'default' => 'SMS bilgilendirmesi almak istediğiniz durumları seçin'
				),
				array(
					'name'    => 'buyer_select_status_text_bellow',
					'label'   => 'SMS durum tercih kısmı alt metni',
					'desc'    => 'Müşteri SMS durum tercihi kısmı için alt kısımda görünecek açıklama.',
					'type'    => 'text',
					'default' => 'Seçtiğiniz durumlarda size SMS bilgilendirmesi yapılacak'
				),
				array(
					'name'  => 'header_3',
					'label' => '<h2>İşlem durumuna göre müşteriye gidecek otomatik SMS içeriği ayarları </h2>',
					'type'  => 'html',
				),
				array(
					'name'  => 'sms_body_shortcodes',
					'label' => 'Kullanılabilir kısa kodlar',
					'type'  => 'html',
					'desc'  => $this->ShortCodes(),
				),
			) ),

			'sms_product_admin_settings' => apply_filters( 'pwoosms_product_admin_settings', array(
				array(
					'name'    => 'enable_product_admin_sms',
					'label'   => 'Ürün satıcılarına SMS gönderme',
					'desc'    => 'Bu seçeneği etkinleştirdiğinizde, siparişi kaydederken veya değiştirirken her ürünün (satıcıların) yöneticilerine bir SMS gönderilir.',
					'type'    => 'checkbox',
					'default' => 'no'
				),
				array(
					'name'    => 'product_admin_user_meta',
					'label'   => 'Mobil meta satıcıların kullanıcıları (isteğe bağlı)',
					'desc'    => 'Yukarıdaki seçeneği etkinleştirerek, yani "ürün satıcılarına SMS gönderme", her ürünün düzenlenmesi ve yönetimi içinde, "SMS" adlı yeni bir sekme eklenecektir; burada mobil satıcı sayısını (ürün yöneticileri) manuel olarak girebilirsiniz. Bununla birlikte, her bir ürünün satıcısının cep telefonu numarasını manuel olarak girmenin çok zor ve zaman alıcı bir görev olması nedeniyle, bu alandaki satıcıların cep telefonu numarasıyla ilgili kullanıcı meta anahtarını veya Kullanıcı Meta Anahtarını otomatik olarak girmek mümkün olacaktır. Söz konusu meta için kayıtlı cep telefonuna SMS gönderin. <br> Bu özellik genellikle WooCommerce çok satıcılı eklentileri kullanılırken kullanılır. Bu konuda yeterli bilginiz yoksa, endişelenmeden boş bırakın.',
					'type'    => 'text',
					'ltr'     => true,
					'default' => ''
				),
				array(
					'name'    => 'product_admin_post_meta',
					'label'   => 'Mobil Meta Satıcı Gönderisi (İsteğe Bağlı)',
					'desc'    => 'Bazen satıcının post_meta sında user_meta yerine satıcıların cep telefonu numaralarını kaydetmek için başka bazı WooCommerce çok satıcılı eklentileri veya kişisel kodlama kullanabilirsiniz; bu durumda meta kullanıcı yerine meta ve posta kullanabilirsiniz Veya her ikisini de kullanın. Ayrıca, bu konuda yeterli bilginiz yoksa, endişelenmeden boş bırakın.',
					'type'    => 'text',
					'ltr'     => true,
					'default' => ''
				),
				array(
					'name'    => 'product_admin_meta_order_status',
					'label'   => 'SMS alma durumu',
					'desc'    => 'Bu SMS makbuzları user_meta veya post_meta aracılığıyla kurulan satıcılar için geçerli olacaktır. Ürüne manuel olarak eklenen satıcıların SMS durumunu ayarlamak için aynı ürünün düzenleme sayfasına gidebilir ve SMS sekmesini, ürün yöneticisinin cep telefonu numarasını ve ilgili sipariş durumunu ekleyebilirsiniz.',
					'type'    => 'multicheck',
					'options' => PWooSMS()->GetAllSuperAdminStatuses(),
				),
				array(
					'name'  => 'header_product_admin',
					'label' => '<h2>Ürün satıcılarının SMS metni</h2>',
					'type'  => 'html',
				),
				array(
					'name'  => 'sms_body_shortcodes_product_admin',
					'label' => 'Kullanılabilir kısa kodlar',
					'type'  => 'html',
					'desc'  => $this->ShortCodes(),
				),
			) ),

			
		);

		return apply_filters( 'pwoosms_settings_fields', $settings_fields );
	}


	public function buyerSettings( $settings ) {

		$statuses = PWooSMS()->GetAllStatuses();

		foreach ( ( array ) $statuses as $status_val => $status_name ) {

			$_status_name = preg_replace( '/\(.*\)/is', '', $status_name );
			$_status_name = trim( $_status_name );

			$text = array(
				array(
					'name'    => 'sms_body_' . $status_val,
					'label'   => 'durum: ' . $status_name,
					'desc'    => "Bu bölümün üst kısmında verilen kısa kodları kullanabilirsiniz.",
					'type'    => 'textarea',
					'default' => "Merhaba {b_first_name} {b_last_name}\n {order_id} siparişi alındı ve şu anda " . $_status_name . " durumunda.\nSipariş öğeleri : {all_items}\nSipariş miktarı : {price}\nİşlem numarası : {transaction_id}"

				),
			);

			$settings = array_merge( $settings, $text );
		}


		return $settings;
	}


	public function superAdminSettings( $settings ) {

		$statuses = PWooSMS()->GetAllStatuses();
		foreach ( ( array ) $statuses as $status_val => $status_name ) {

			$_status_name = preg_replace( '/\(.*\)/is', '', $status_name );
			$_status_name = trim( $_status_name );

			$text = array(
				array(
					'name'    => 'super_admin_sms_body_' . $status_val,
					'label'   => 'durum: ' . $status_name,
					'desc'    => "Bu bölümün üst kısmında verilen kısa kodları kullanabilirsiniz.",
					'type'    => 'textarea',
					'row'     => 5,
					'default' => "Merhaba yönetici\n{order_id} siparişi kaydedildi ve şu anda " . $_status_name . " durumunda.\nSipariş öğeleri : {all_items}\nSipariş tutarı : {price}"
				)
			);

			$settings = array_merge( $settings, $text );
		}

		$text     = array(
			array(
				'name'  => 'header_3',
				'label' => '<h2>Depo envanteri SMS Mesaji</h2>',
				'desc'  => '"Envanter ve depo" metin mesajları metninin "Ürün Satıcıları" için de geçerli olacağını ve depo envanter ayarlarının ve eşiklerinin WooCommerce ayarlarına bağlı olduğunu unutmayın. <a href="' . admin_url( 'admin.php?page=wc-settings&tab=products&section=inventory' ) . '" target="_blank">depo envanter ayarları</a>',
				'type'  => 'html',
			),
			array(
				'name'  => 'header_4',
				'label' => 'Kullanılabilir kısa kodlar',
				'desc'  => "Kullanılabilir kısa kodlar :<br><code>{product_id}</code> : Ürün id، <code>{sku}</code> : Ürün Kimliği، <code>{product_title}</code> : Ürün başlığı، <code>{stock}</code> : Depo envanteri",
				'type'  => 'html',
			),
			array(
				'name'    => 'admin_low_stock',
				'label'   => 'Düşük envanter',
				'desc'    => "Envanter az olduğunda SMS metni.",
				'type'    => 'textarea',
				'row'     => 3,
				'default' => "Merhaba\n{product_title} , Ürün deposu envanteri tükeniyor."
			),
			array(
				'name'    => 'admin_out_stock',
				'label'   => 'Envanter sonu',
				'desc'    => "Envanter tükendi SMS metni.",
				'type'    => 'textarea',
				'row'     => 3,
				'default' => "Merhaba\n{product_title}, Ürün deposunun envanteri tükendi."
			),
		);
		$settings = array_merge( $settings, $text );

		return $settings;
	}


	public function productAdminSettings( $settings ) {

		$statuses = PWooSMS()->GetAllStatuses();

		foreach ( ( array ) $statuses as $status_val => $status_name ) {

			$_status_name = preg_replace( '/\(.*\)/is', '', $status_name );
			$_status_name = trim( $_status_name );

			$text = array(
				array(
					'name'    => 'product_admin_sms_body_' . $status_val,
					'label'   => 'durum: ' . $status_name,
					'desc'    => "Bu bölümün üst kısmında verilen kısa kodları kullanabilirsiniz.",
					'type'    => 'textarea',
					'row'     => 4,
					'default' => "Merhaba\n{Order_id} siparişi kaydedildi ve şu anda " . $_status_name . " Durumunda.\n Size ait sipariş öğeleri: {vendor_items}",
				),
			);

			$settings = array_merge( $settings, $text );
		}

		$text = array(
			array(
				'name'  => 'sms_body_stock_product_admin',
				'label' => '<h2>Depo Mesaj</h2>',
				'desc'  => sprintf( '<a href="' . admin_url( 'admin.php?page=vatansms-woocommerce-sms-pro&tab=super_admin#sms_super_admin_settings[admin_low_stock]' ) . '" target="_blank">Deop mesaj ayarlari</a>' ),
				'type'  => 'html',
			)
		);

		$settings = array_merge( $settings, $text );

		return $settings;
	}


	public function ShortCodes() {

		$shortcode_list = apply_filters( 'pwoosms_shortcodes_list', '' );

		$product_admin_shortcodes = '';

		if ( ! empty( $_GET['tab'] ) && $_GET['tab'] == 'product_admin' ) {
			$product_admin_shortcodes = "
				<strong>Satıcılar için özel kısa kodlar: </strong><br>
				<code>{vendor_items}</code> = Herhangi bir satıcıdan ürün sipariş edilen   ، 
				<code>{vendor_items_qty}</code> = Her satıcıdan sipariş edilen ürün sayısı  ،<br>
				<code>{count_vendor_items}</code> = satıcıdan sipariş edilen ürün Toplam sayısı   ،
				<code>{vendor_price}</code> = satıcıdan sipariş edilen ürün toplam fıyatı   ، <br><br>
			";
		}

		return "
		<a href='' onclick='jQuery(\".pwoosms_settings_shortcodes\").slideToggle(); return false;' style='text-decoration: none;'>
			Kısa mesajların metninde kullanılabilecek kısa kodları görmek için tıklayın.
		</a>
		<div class='pwoosms_settings_shortcodes' style='display: none'>
			<strong>Sipariş ayrıntıları : </strong><br>
			<code>{mobile}</code> = Müşteri cep telefonu numarası   ، 
			<code>{phone}</code> = Müşteri telefon numarası   ،
			<code>{email}</code> = Müşteri e-postası   ،
			<code>{status}</code> = Sipariş durumu   ، <br>
			<code>{all_items}</code> = Ürün siparişi   ،
			<code>{all_items_qty}</code> = Sipariş edilen ürün Toplam sayısı   ،
			<code>{count_items}</code> = Sipariş edilen her ürün sayısı   ،<br>
			<code>{price}</code> = Sipariş miktarı   ،
			<code>{post_id}</code> = Orijinal sipariş numarası   ، 
			<code>{order_id}</code> = Sipariş numarası   ،
			<code>{transaction_id}</code> = İşlem numarası   ،<br>
			<code>{date}</code> = Sipariş Tarihi   ،
			<code>{description}</code> = Müşteri açıklaması   ،
			<code>{payment_method}</code> = Ödeme şeklı   ،
			<code>{shipping_method}</code> = Kargo şeklı  ،<br><br>
		
			<strong>Hesap ayrıntıları : </strong><br>
			<code>{b_first_name}</code> = Müşteri adı   ،
			<code>{b_last_name}</code> = Müşterinin soyadı   ،
			<code>{b_company}</code> = Şirket adı   ،
			<code>{b_country}</code> = ülke   ،<br>
			<code>{b_state}</code> = İl/İlçe  ،
			<code>{b_city}</code> = şehir   ،
			<code>{b_address_1}</code> = Adres 1   ،
			<code>{b_address_2}</code> = Adres 2   ،
			<code>{b_postcode}</code> = Posta kodu   ،<br><br>
		
			<strong>Kargo detayları : </strong><br>
			<code>{sh_first_name}</code> = Müşteri adı   ،
			<code>{sh_last_name}</code> = Müşterinin soyadı   ،
			<code>{sh_company}</code> = Şirket adı   ،
			<code>{sh_country}</code> = ülke   ،<br>  
			<code>{sh_state}</code> = İl/İlçe   ،
			<code>{sh_city}</code> = şehir   ،
			<code>{sh_address_1}</code> = Adres 1   ،
			<code>{sh_address_2}</code> = Adres 2   ،
			<code>{sh_postcode}</code> = Posta kodu   ،<br><br>
		
			{$product_admin_shortcodes}
		
			{$shortcode_list}
		</div>
	";
	}
	
	public function footerNote( $text ) {
		if ( isset( $_GET['page'] ) && $_GET['page'] == 'vatansms-woocommerce-sms-pro' ) {
			return ' <a href="http://vatansms.com/" target="_blank">VatanSMS</a>';
		}

		return $text;
	}

	public function footerVersion( $text ) {
		if ( isset( $_GET['page'] ) && $_GET['page'] == 'vatansms-woocommerce-sms-pro' ) {
			$text = 'Version ' . PWOOSMS_VERSION;
		}

		return $text;
	}
}

new Vatansms_SMS_Settings();